==> estateplat-common-1.1.0-20160929.061240-200-sources.jar: cn/gtmap/estateplat/model/exchange/transition/QzYydj.java <==
package cn.gtmap.estateplat.model.exchange.transition;

import javax.persistence.Id;
import javax.persistence.Table;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import java.io.Serializable;
import java.util.Date;

/**
 * Created with IntelliJ IDEA.
 * 异议登记
 * User: lj
 * Date: 15-11-19
 * Time: 下午2:25
 * To change this template use File | Settings | File Templates.
 */
@Table(name = "qz_yydj")
@XmlAccessorType(XmlAccessType.FIELD)
public class QzYydj implements Serializable {
    @Id
    //权利编号
    @XmlElement(name = "qlbh")
    private String qlbh;
    //不动产单元编号
    @XmlElement(name = "bdcdybh")
    private String bdcdybh;
    //业务号
    @XmlElement(name = "ywh")
    private String ywh;
    //异议事项
    @XmlElement(name = "yysx")
    private String yysx;
    //注销异议业务号
    @XmlElement(name = "zxyyywh")
    private String zxyyywh;
    //注销异议原因
    @XmlElement(name = "zxyyyy")
    private String zxyyyy;
    //注销异议登簿人
    @XmlElement(name = "zxyydbr")
    private String zxyydbr;
    //注销异议登记时间
    @XmlElement(name = "zxyydjsj")
    private Date zxyydjsj;
    //备注
    @XmlElement(name = "bz")
    private String bz;
    //其他
    @XmlElement(name = "qt")
    private String qt;

    //涉及相关证书、证明进行转移、变更时，填写对应证书、证明的不动产登记的上次业务号
    private String yywh;

    //涉及相关证书、证明进行转移、变更时，填写对应证书、证明的不动产登记的上次产权证号
    private String ycqzh;

    public String getYywh() {
        return yywh;
    }

    public void setYywh(String yywh) {
        this.yywh = yywh;
    }


    public String getQlbh() {
        return qlbh;
    }

    public void setQlbh(String qlbh) {
        this.qlbh = qlbh;
    }

    public String getBdcdybh() {
        return bdcdybh;
    }

    public void setBdcdybh(String bdcdybh) {
        this.bdcdybh = bdcdybh;
    }

    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public String getYysx() {
        return yysx;
    }

    public void setYysx(String yysx) {
        this.yysx = yysx;
    }

    public String getZxyyywh() {
        return zxyyywh;
    }

    public void setZxyyywh(String zxyyywh) {
        this.zxyyywh = zxyyywh;
    }

    public String getZxyyyy() {
        return zxyyyy;
    }

    public void setZxyyyy(String zxyyyy) {
        this.zxyyyy = zxyyyy;
    }

    public String getZxyydbr() {
        return zxyydbr;
    }

    public void setZxyydbr(String zxyydbr) {
        this.zxyydbr = zxyydbr;
    }

    public Date getZxyydjsj() {
        return zxyydjsj;
    }

    public void setZxyydjsj(Date zxyydjsj) {
        this.zxyydjsj = zxyydjsj;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getQt() {
        return qt;
    }

    public void setQt(String qt) {
        this.qt = qt;
    }

    public String getYcqzh() {
        return ycqzh;
    }

    public void setYcqzh(String ycqzh) {
        this.ycqzh = ycqzh;
    }
}

==> estateplat-common-1.2.4-20250919.082234-1309-sources.jar: cn/gtmap/estateplat/model/exchange/transition/QzYydj.java <==
package cn.gtmap.estateplat.model.exchange.transition;

import javax.persistence.Id;
import javax.persistence.Table;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import java.io.Serializable;
import java.util.Date;

/**
 * Created with IntelliJ IDEA.
 * 异议登记
 * User: lj
 * Date: 15-11-19
 * Time: 下午2:25
 * To change this template use File | Settings | File Templates.
 */
@Table(name = "qz_yydj")
@XmlAccessorType(XmlAccessType.FIELD)
public class QzYydj implements Serializable {
    @Id
    //权利编号
    @XmlElement(name = "qlbh")
    private String qlbh;
    //不动产单元编号
    @XmlElement(name = "bdcdybh")
    private String bdcdybh;
    //业务号
    @XmlElement(name = "ywh")
    private String ywh;
    //异议事项
    @XmlElement(name = "yysx")
    private String yysx;
    //注销异议业务号
    @XmlElement(name = "zxyyywh")
    private String zxyyywh;
    //注销异议原因
    @XmlElement(name = "zxyyyy")
    private String zxyyyy;
    //注销异议登簿人
    @XmlElement(name = "zxyydbr")
    private String zxyydbr;
    //注销异议登记时间
    @XmlElement(name = "zxyydjsj")
    private Date zxyydjsj;
    //备注
    @XmlElement(name = "bz")
    private String bz;
    //其他
    @XmlElement(name = "qt")
    private String qt;

    //涉及相关证书、证明进行转移、变更时，填写对应证书、证明的不动产登记的上次业务号
    private String yywh;

    //涉及相关证书、证明进行转移、变更时，填写对应证书、证明的不动产登记的上次产权证号
    private String ycqzh;

    //登簿人
    @XmlElement(name = "dbr")
    private String dbr;

    public String getDbr() {
        return dbr;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }

    public String getYywh() {
        return yywh;
    }

    public void setYywh(String yywh) {
        this.yywh = yywh;
    }


    public String getQlbh() {
        return qlbh;
    }

    public void setQlbh(String qlbh) {
        this.qlbh = qlbh;
    }

    public String getBdcdybh() {
        return bdcdybh;
    }

    public void setBdcdybh(String bdcdybh) {
        this.bdcdybh = bdcdybh;
    }

    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public String getYysx() {
        return yysx;
    }

    public void setYysx(String yysx) {
        this.yysx = yysx;
    }

    public String getZxyyywh() {
        return zxyyywh;
    }

    public void setZxyyywh(String zxyyywh) {
        this.zxyyywh = zxyyywh;
    }

    public String getZxyyyy() {
        return zxyyyy;
    }

    public void setZxyyyy(String zxyyyy) {
        this.zxyyyy = zxyyyy;
    }

    public String getZxyydbr() {
        return zxyydbr;
    }

    public void setZxyydbr(String zxyydbr) {
        this.zxyydbr = zxyydbr;
    }

    public Date getZxyydjsj() {
        return zxyydjsj;
    }

    public void setZxyydjsj(Date zxyydjsj) {
        this.zxyydjsj = zxyydjsj;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getQt() {
        return qt;
    }

    public void setQt(String qt) {
        this.qt = qt;
    }

    public String getYcqzh() {
        return ycqzh;
    }

    public void setYcqzh(String ycqzh) {
        this.ycqzh = ycqzh;
    }
}
